#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 genvalidity
version:              0.11.0.0
visibility:           public
id:                   genvalidity-0.11.0.0-1rHtmJxHPr6Agj17dAQvrg
key:                  genvalidity-0.11.0.0-1rHtmJxHPr6Agj17dAQvrg
license:              MIT
copyright:            Copyright: (c) 2016-2020 Tom Sydney Kerckhove
maintainer:           syd@cs-syd.eu
author:               Tom Sydney Kerckhove
homepage:             https://github.com/NorfairKing/validity#readme
synopsis:             Testing utilities for the validity library
description:
    Note: There are companion instance packages for this library:

    * <https://hackage.haskell.org/package/genvalidity-aeson genvalidity-aeson>

    * <https://hackage.haskell.org/package/genvalidity-bytestring genvalidity-bytestring>

    * <https://hackage.haskell.org/package/genvalidity-containers genvalidity-containers>

    * <https://hackage.haskell.org/package/genvalidity-path genvalidity-path>

    * <https://hackage.haskell.org/package/genvalidity-scientific genvalidity-scientific>

    * <https://hackage.haskell.org/package/genvalidity-text genvalidity-text>

    * <https://hackage.haskell.org/package/genvalidity-time genvalidity-time>

    * <https://hackage.haskell.org/package/genvalidity-unordered-containers genvalidity-unordered-containers>

    * <https://hackage.haskell.org/package/genvalidity-uuid genvalidity-uuid>

    * <https://hackage.haskell.org/package/genvalidity-vector genvalidity-vector>

category:             Testing
abi:                  b53ea245fdd1e30049e0a95673628af3
exposed:              True
exposed-modules:
    Data.GenRelativeValidity Data.GenValidity Data.GenValidity.Utils

hidden-modules:       Paths_genvalidity
import-dirs:          /usr/lib/ghc-8.10.5/site-local/genvalidity-0.11.0.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/genvalidity-0.11.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/genvalidity-0.11.0.0
hs-libraries:         HSgenvalidity-0.11.0.0-1rHtmJxHPr6Agj17dAQvrg
depends:
    QuickCheck-2.14.2-LYkEXWaccd95SoKseYSYTk base-4.14.2.0
    random-1.2.0-BSVdQCE475yEKcUUPfL4ub
    validity-0.11.0.0-6HjzlFoUGIE70AmpbEbG5p

haddock-interfaces:   /usr/share/doc/haskell-genvalidity/html/genvalidity.haddock
haddock-html:         /usr/share/doc/haskell-genvalidity/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

